@@ -4,7 +4,7 @@ import tempfile
 
 import pytest
 
-import vdb.lib.storage as storage
+from vdb.lib import storage as storage
 from vdb.lib.gha import GitHubSource
 from vdb.lib.nvd import NvdSource
 
