@@ -12,12 +12,12 @@ import logging
 import os
 import re
 
+import orjson
 import requests
-import ujson
 
 from vdb.lib import config as config
 from vdb.lib.nvd import NvdSource
-from vdb.lib.utils import fix_text, get_default_cve_data
+from vdb.lib.utils import get_default_cve_data
 
 logging.basicConfig(
     level=logging.INFO, format="%(levelname)s [%(asctime)s] %(message)s"
@@ -238,7 +238,7 @@ class GitHubSource(NvdSource):
                     cve_id=cve_id,
                     cwe_id="UNKNOWN",
                     assigner=assigner,
-                    references=ujson.dumps(references),
+                    references=orjson.dumps(references).decode("utf-8"),
                     description="",
                     vectorString=vectorString,
                     vendor=vendor.lower(),
@@ -260,10 +260,10 @@ class GitHubSource(NvdSource):
                     lastModifiedDate=cve["updatedAt"],
                 )
                 try:
-                    tdata_json = ujson.loads(tdata)
+                    tdata_json = orjson.loads(tdata)
                     vuln = NvdSource.convert_vuln(tdata_json)
                     vuln.description = description
                     ret_data.append(vuln)
-                except Exception:
-                    LOG.warning(tdata)
+                except Exception as e:
+                    LOG.debug(e)
         return ret_data, page_info
