@@ -5,8 +5,8 @@ This module implements basic functionality to query npm registry for security ad
 """
 import logging
 
+import orjson
 import requests
-import ujson
 
 from vdb.lib import config as config
 from vdb.lib.nvd import NvdSource
@@ -227,7 +227,7 @@ class NpmSource(NvdSource):
                     cve_id=cve_id,
                     cwe_id=cwe_id,
                     assigner=assigner,
-                    references=ujson.dumps(references),
+                    references=orjson.dumps(references).decode("utf-8"),
                     description="",
                     vectorString=vectorString,
                     vendor=vendor,
@@ -249,7 +249,7 @@ class NpmSource(NvdSource):
                     lastModifiedDate=lastModifiedDate,
                 )
                 try:
-                    vuln = NvdSource.convert_vuln(ujson.loads(tdata))
+                    vuln = NvdSource.convert_vuln(orjson.loads(tdata))
                     vuln.description = description
                     ret_data.append(vuln)
                 except Exception:
