@@ -3,8 +3,8 @@ import gzip
 import logging
 import tempfile
 
+import orjson
 import requests
-import ujson
 
 from vdb.lib import CvssV3, Vulnerability, VulnerabilityDetail, VulnerabilitySource
 from vdb.lib import config as config
@@ -73,7 +73,7 @@ class NvdSource(VulnerabilitySource):
             with gzip.open(tf.name, "rb") as gzipjf:
                 cve_data = gzipjf.read()
                 try:
-                    json_data = ujson.loads(cve_data)
+                    json_data = orjson.loads(cve_data)
                     return self.convert(json_data)
                 except Exception:
                     logging.warning("Exception while parsing NVD CVE feed")
